pub fn children<N: AstNode>(parent: &SyntaxNode) -> impl Iterator<Item = N>Expand description
All child nodes castable to N, in source order.
pub fn children<N: AstNode>(parent: &SyntaxNode) -> impl Iterator<Item = N>All child nodes castable to N, in source order.