first_group_range

Function first_group_range 

pub fn first_group_range(command: &SyntaxNode) -> TextRange
The byte range of command spanning its control word through the end of its first {…} group; the full command range when the first group is absent.