pub fn argument_domain(group: &SyntaxNode) -> ArgumentDomainExpand description
Return the curated positional domain of an attached argument group. Unowned, unmatched, over-attached, and unknown-owner groups are unknown.
pub fn argument_domain(group: &SyntaxNode) -> ArgumentDomainReturn the curated positional domain of an attached argument group. Unowned, unmatched, over-attached, and unknown-owner groups are unknown.