pub struct ArgSpec {
pub required: bool,
pub kind: ArgKind,
pub content: ContentKind,
pub domain: ArgumentDomain,
pub verbatim: bool,
}Expand description
One argument slot in a command/environment signature.
Fields
required: boolWhether the argument must be present, independently of its delimiter kind.
kind: ArgKindcontent: ContentKindHow the formatter treats this argument’s content. See ContentKind.
domain: ArgumentDomainThe mode established by this positional argument, independently of
ContentKind.
verbatim: boolWhether this braced argument is read under a curated raw-text lexer mode.
Independent of formatter ContentKind and text-or-math
ArgumentDomain.