pub fn first_group_range(command: &SyntaxNode) -> TextRangeExpand description
The byte range of command spanning its control word through the end of its
first {…} group; the full command range when the first group is absent.
pub fn first_group_range(command: &SyntaxNode) -> TextRangeThe byte range of command spanning its control word through the end of its
first {…} group; the full command range when the first group is absent.