pub fn reparse(
base: &ReparseBase<'_>,
edit: &Edit,
new_text: &str,
) -> Option<Reparsed>Expand description
Attempt an incremental reparse of base under edit, which transforms
base.text into new_text. None means no tier applied and the caller must
do a full parse.